package
Version:
v0.0.0-...-3a28f6d
Opens a new window with list of versions in this module.
Published: Apr 8, 2024
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Config struct {
BTCPay struct {
URL string `yaml:"url"`
Username string `yaml:"username,omitempty"`
Password string `yaml:"password,omitempty"`
APIKey string `yaml:"apiKey,omitempty"`
} `yaml:"BTCPayServer"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.